"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ColorModeProvider = ColorModeProvider;
exports.useColorModeValue = useColorModeValue;
exports.useColorMode = exports.ColorModeContext = void 0;

var _react = _interopRequireWildcard(require("react"));

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function () { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const ColorModeContext = /*#__PURE__*/_react.default.createContext({});

exports.ColorModeContext = ColorModeContext;

function useModeManager(initialColorMode, colorModeManager) {
  const [colorMode, setRawMode] = (0, _react.useState)();

  async function setColorMode(val) {
    if (colorModeManager) {
      await colorModeManager.set(val);
    }

    setRawMode(val);
  } // For initial setting initial color mode from storage


  (0, _react.useEffect)(() => {
    if (colorModeManager) {
      (async function getMode() {
        let value = await colorModeManager.get(initialColorMode);
        setRawMode(value);
      })();
    } else {
      setRawMode(initialColorMode);
    }
  }, [initialColorMode, colorModeManager]);
  return {
    colorMode,
    setColorMode
  };
}

function ColorModeProvider(props) {
  const {
    value,
    children,
    options: {
      initialColorMode
    },
    colorModeManager
  } = props;
  const {
    colorMode,
    setColorMode
  } = useModeManager(initialColorMode, colorModeManager);

  const toggleColorMode = _react.default.useCallback(() => {
    setColorMode(colorMode === 'light' ? 'dark' : 'light');
  }, [colorMode, setColorMode]);

  const context = {
    colorMode: value !== null && value !== void 0 ? value : colorMode,
    toggleColorMode: value ? () => {} : toggleColorMode,
    setColorMode: value ? () => {} : setColorMode
  };
  return /*#__PURE__*/_react.default.createElement(ColorModeContext.Provider, {
    value: context
  }, children);
}

const useColorMode = () => {
  const context = _react.default.useContext(ColorModeContext);

  if (context === undefined) {
    throw new Error('useColorMode must be used within a ColorModeProvider');
  }

  return context;
};

exports.useColorMode = useColorMode;

function useColorModeValue(light, dark) {
  const {
    colorMode
  } = useColorMode();
  return colorMode === 'dark' ? dark : light;
}
//# sourceMappingURL=provider.js.map