import React, { useState, useEffect } from 'react';
export const ColorModeContext = /*#__PURE__*/React.createContext({});

function useModeManager(initialColorMode, colorModeManager) {
  const [colorMode, setRawMode] = useState();

  async function setColorMode(val) {
    if (colorModeManager) {
      await colorModeManager.set(val);
    }

    setRawMode(val);
  } // For initial setting initial color mode from storage


  useEffect(() => {
    if (colorModeManager) {
      (async function getMode() {
        let value = await colorModeManager.get(initialColorMode);
        setRawMode(value);
      })();
    } else {
      setRawMode(initialColorMode);
    }
  }, [initialColorMode, colorModeManager]);
  return {
    colorMode,
    setColorMode
  };
}

export function ColorModeProvider(props) {
  const {
    value,
    children,
    options: {
      initialColorMode
    },
    colorModeManager
  } = props;
  const {
    colorMode,
    setColorMode
  } = useModeManager(initialColorMode, colorModeManager);
  const toggleColorMode = React.useCallback(() => {
    setColorMode(colorMode === 'light' ? 'dark' : 'light');
  }, [colorMode, setColorMode]);
  const context = {
    colorMode: value !== null && value !== void 0 ? value : colorMode,
    toggleColorMode: value ? () => {} : toggleColorMode,
    setColorMode: value ? () => {} : setColorMode
  };
  return /*#__PURE__*/React.createElement(ColorModeContext.Provider, {
    value: context
  }, children);
}
export const useColorMode = () => {
  const context = React.useContext(ColorModeContext);

  if (context === undefined) {
    throw new Error('useColorMode must be used within a ColorModeProvider');
  }

  return context;
};
export function useColorModeValue(light, dark) {
  const {
    colorMode
  } = useColorMode();
  return colorMode === 'dark' ? dark : light;
}
//# sourceMappingURL=provider.js.map